@@ -18,8 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-
-
 #define G_LOG_DOMAIN "ide-frame"
 
 #include "config.h"
@@ -79,7 +77,7 @@ typedef struct
   IdePage              *pan_page;
 
   /* Template references */
-  DzlBox               *empty_state;
+  GtkBox               *empty_placeholder;
   DzlEmptyState        *failed_state;
   IdeFrameHeader       *header;
   GtkStack             *stack;
@@ -107,11 +105,13 @@ enum {
   N_SIGNALS
 };
 
+static void buildable_iface_init     (GtkBuildableIface   *iface);
 static void list_model_iface_init    (GListModelInterface *iface);
 static void animation_state_complete (gpointer             data);
 
 G_DEFINE_TYPE_WITH_CODE (IdeFrame, ide_frame, GTK_TYPE_BOX,
                          G_ADD_PRIVATE (IdeFrame)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, buildable_iface_init)
                          G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, list_model_iface_init))
 
 static GParamSpec *properties [N_PROPS];
@@ -238,7 +238,7 @@ ide_frame_notify_visible_child (IdeFrame   *self,
   else if (visible_child != NULL)
     gtk_stack_set_visible_child (priv->top_stack, GTK_WIDGET (priv->stack));
   else
-    gtk_stack_set_visible_child (priv->top_stack, GTK_WIDGET (priv->empty_state));
+    gtk_stack_set_visible_child (priv->top_stack, GTK_WIDGET (priv->empty_placeholder));
 
   /* Allow the header to update settings */
   _ide_frame_header_update (priv->header, IDE_PAGE (visible_child));
@@ -873,7 +873,7 @@ ide_frame_class_init (IdeFrameClass *klass)
 
   gtk_widget_class_set_css_name (widget_class, "ideframe");
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/libide-gui/ui/ide-frame.ui");
-  gtk_widget_class_bind_template_child_private (widget_class, IdeFrame, empty_state);
+  gtk_widget_class_bind_template_child_private (widget_class, IdeFrame, empty_placeholder);
   gtk_widget_class_bind_template_child_private (widget_class, IdeFrame, failed_state);
   gtk_widget_class_bind_template_child_private (widget_class, IdeFrame, header);
   gtk_widget_class_bind_template_child_private (widget_class, IdeFrame, stack);
@@ -1411,3 +1411,41 @@ ide_frame_add_with_depth (IdeFrame  *self,
                                      "position", position,
                                      NULL);
 }
+
+static void
+ide_frame_add_child (GtkBuildable *buildable,
+                     GtkBuilder   *builder,
+                     GObject      *object,
+                     const gchar  *type)
+{
+  IdeFrame *self = (IdeFrame *)buildable;
+  GtkBuildableIface *parent = g_type_interface_peek_parent (GTK_BUILDABLE_GET_IFACE (buildable));
+
+  if (g_strcmp0 (type, "placeholder") == 0 && GTK_IS_WIDGET (object))
+    ide_frame_set_placeholder (self, GTK_WIDGET (object));
+  else
+    parent->add_child (buildable, builder, object, type);
+}
+
+static void
+buildable_iface_init (GtkBuildableIface *iface)
+{
+  iface->add_child = ide_frame_add_child;
+}
+
+void
+ide_frame_set_placeholder (IdeFrame  *self,
+                           GtkWidget *placeholder)
+{
+  IdeFramePrivate *priv = ide_frame_get_instance_private (self);
+
+  g_return_if_fail (IDE_IS_FRAME (self));
+  g_return_if_fail (!placeholder || GTK_IS_WIDGET (placeholder));
+
+  gtk_container_foreach (GTK_CONTAINER (priv->empty_placeholder),
+                         (GtkCallback) gtk_widget_destroy,
+                         NULL);
+
+  if (placeholder != NULL)
+    gtk_container_add (GTK_CONTAINER (priv->empty_placeholder), placeholder);
+}
