@@ -34,6 +34,7 @@
 #include "ide-transfer-manager-private.h"
 
 #include "ide-application.h"
+#include "ide-command-manager.h"
 #include "ide-gui-global.h"
 #include "ide-gui-private.h"
 #include "ide-primary-workspace.h"
@@ -380,6 +381,9 @@ ide_workbench_constructed (GObject *object)
   peas_extension_set_foreach (self->addins,
                               ide_workbench_addin_added_cb,
                               self);
+
+  /* Load command providers (which may register shortcuts) */
+  (void)ide_command_manager_from_context (self->context);
 }
 
 static void
@@ -765,6 +769,7 @@ ide_workbench_add_workspace (IdeWorkbench *self,
                              IdeWorkspace *workspace)
 {
   g_autoptr(GPtrArray) addins = NULL;
+  IdeCommandManager *command_manager;
   GList *mru_link;
 
   g_return_if_fail (IDE_IS_MAIN_THREAD ());
@@ -838,6 +843,10 @@ ide_workbench_add_workspace (IdeWorkbench *self,
       formatted = g_strdup_printf (_("Builder — %s"), title);
       gtk_window_set_title (GTK_WINDOW (workspace), formatted);
     }
+
+  /* Load shortcuts for commands */
+  command_manager = ide_command_manager_from_context (self->context);
+  _ide_command_manager_init_shortcuts (command_manager, workspace);
 }
 
 /**
@@ -854,6 +863,7 @@ ide_workbench_remove_workspace (IdeWorkbench *self,
                                 IdeWorkspace *workspace)
 {
   g_autoptr(GPtrArray) addins = NULL;
+  IdeCommandManager *command_manager;
   GList *list;
   GList *mru_link;
   guint count = 0;
@@ -869,6 +879,10 @@ ide_workbench_remove_workspace (IdeWorkbench *self,
                                         G_CALLBACK (ide_workbench_workspace_has_toplevel_focus_cb),
                                         self);
 
+  /* Remove any shortcuts that were registered by command providers */
+  command_manager = ide_command_manager_from_context (self->context);
+  _ide_command_manager_unload_shortcuts (command_manager, workspace);
+
   /* Notify all the addins about losing the workspace. */
   if ((addins = ide_workbench_collect_addins (self)))
     {
