@@ -1,6 +1,6 @@
 /* ide-python-indenter.c
  *
- * Copyright 2014-2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2014-2019 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,12 +14,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #define G_LOG_DOMAIN "ide-python-indenter"
 
-#include <libpeas/peas.h>
 #include <gtksourceview/gtksource.h>
+#include <libide-sourceview.h>
 #include <string.h>
 
 #include "ide-python-indenter.h"
